Changelog
=========

.. Use the following to start a new version entry:

   |version| (unreleased)
   ----------------------

   - change message [author]

1.0 (2011-10-21)
----------------

- Initial release. [pumazi]
